// Replication: Mortgage Analysis 
** This file runs in the process of running Replication_master.do
** This file replicates results from section "Effects of Variation in Civil Law: American Indian Housing."
** Note: Summary tables 1a-1d can also be generated from this data.

clear all
set more off

use QJPSReplicationdata_mortgage.dta
set matsize 1500

*******************
* Background Notes
*******************

/* 
Note: Replacing observations from retroceeded tribes with observations of 0 for PL280.
gen pl280_edit=pl280
** Ute Mountain Tribe - NA (1984)
replace pl280_edit=0 if state=="CO" & hud_city=="Towaoc"
** Red Lake Tribe - NA (1953)
replace pl280_edit=0 if state=="MN" & hud_city=="Red Lake"
replace pl280_edit=0 if state=="MN" & hud_city=="Redby"
replace pl280_edit=0 if state=="MN" & hud_city=="Little Rock"
replace pl280_edit=0 if state=="MN" & hud_city=="Ponemah"
** Bois Forte - NA (1975)
replace pl280_edit=0 if state=="MN" & hud_city=="Nett Lake"
replace pl280_edit=0 if state=="MN" & hud_city=="Vermillioin"
replace pl280_edit=0 if state=="MN" & hud_city=="Deer Creek"
** Omaha Tribe - NA (1970)
replace pl280_edit=0 if state=="NE" & hud_city=="Macy"
** Santee Sioux Tribe - NA (2006)
replace pl280_edit=0 if state=="NE" & hud_city=="Niobrara" & year>=2006
replace pl280_edit=0 if zip==68760 & year>=2006
** Warm Springs Tribe - NA (1953)
replace pl280_edit=0 if state=="OR" & hud_city=="Warm Springs"
** Umatilla Tribe - NA (1981)
replace pl280_edit=0 if state=="OR" & hud_city=="Pendelton"
** Burns Paiute - NA (1979)
replace pl280_edit=0 if state=="OR" & hud_city=="Burns"
replace pl280_edit=0 if zip==97720
** Kickapoo Traditional Tribe - NA (1987)
replace pl280_edit=0 if state=="TX" & hud_city=="Eagle Pass"
** Goshute - NA (1980)
replace pl280_edit=0 if state=="UT" & hud_city=="Tooele"
replace pl280_edit=0 if zip==84074
** Shoshoni - NA (1980)
replace pl280_edit=0 if state=="UT" & hud_city=="Brigham City"
replace pl280_edit=0 if zip==84302
** Ute Mountain Tribe - NA (1980)
replace pl280_edit=0 if state=="UT" & hud_city=="White Mesa"
** Ute Mountain Tribe - NA (1980)
replace pl280_edit=0 if state=="WI" & hud_city=="Keshena"
replace pl280_edit=0 if state=="WI" & hud_city=="Keshana"
replace pl280_edit=0 if zip==54135
replace pl280_edit=0 if zip==54315

label variable pl280_edit "Accurate PL280 (with retrocessions)"
gen pl280onres = pl280_edit*onres
label variable pl280onres "Address on reservation governed by PL280" 
*/

*******************
* Replication
*******************

** Figure 1 **
gen tdif = .
gen tup = .
gen tlo = .
local i = 1
forval x = 1996/2013 {
ttest i if year==`x' & onres==1 , by(pl280_edit)
 
replace year = `x' if _n==`i'
 
replace tdif = `r(mu_1)'-`r(mu_2)' if _n==`i'
replace tup = tdif+1.96*`r(se)' if _n==`i'
replace tlo = tdif-1.96*`r(se)' if _n==`i'
 
local i = `i'+1
}
scatter tdif year || rcap tup tlo year, scheme(s2mono)

*** Table 2 ***
reg i pl280_edit onres i.year if i!=0, r cluster(state)
est store e1
reg i pl280_edit onres pl280onres i.year if i!=0, r cluster(state)
est store e2
reg i pl280_edit onres pl280onres incpc_ln indianppop dist_ln reg15_i reg30_i i.year if i!=0, r cluster(state)
est store e3
estout e1 e2 e3, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)))

** Figure 2 **
reg i pl280_edit onres pl280onres incpc_ln indianppop dist_ln reg15_i reg30_i i.year if i!=0, r cluster(state)
margins, at(pl280onres=(0 1))
marginsplot, recast(scatter) scheme(s2mono) ciopts(lwidth(thick) lpattern(dash))  xscale(range(-.5 1.5))

** Table 3 **
* Summary statistics on lenders can be created from ol_originating lender, sl_servicinglender, and region.
*Count observations by region
by region, sort: gen nobs = _n
gen id = 1 if nobs == 1
by region: replace nobs = nobs[_N]
*Count numbers of originating lenders (column 1)
by region ol_originatinglender, sort: gen nols = _n ==1
by region: replace nols = sum(nols)
by region: replace nols = nols[_N]
*Column 2
gen ratio1 = nobs/nols
replace ratio1 = round(ratio1,1)
*Count numbers of servicing lenders (column 3)
by region sl_servicinglender, sort: gen nsls = _n ==1
by region: replace nsls = sum(nsls)
by region: replace nsls = nsls[_N]
*Column 4
gen ratio2 = nobs/nsls
replace ratio2 = round(ratio2,1)
list region nols ratio1 nsls ratio2 if id == 1




** Table 4 **
reg i pl280_edit onres pl280onres incpc_ln indianppop dist_ln reg15_i reg30_i i.ol i.sl i.year if i!=0, r cluster(state)
est store e1
reg i pl280_edit onres pl280onres incpc_ln indianppop dist_ln reg15_i reg30_i coborrow refi i.ol i.sl i.year if i!=0, r cluster(state)
est store e2
reg i pl280_edit onres pl280onres incpc_ln indianppop dist_ln reg15_i reg30_i coborrow refi loanterm_ln loan_ln i.ol i.sl i.year if i!=0, r cluster(state)
est store e3
reg i pl280_edit onres pl280onres incpc_ln indianppop dist_ln reg15_i reg30_i coborrow refi loanterm_ln loan_ln casinos i.ol i.sl i.year if i!=0, r cluster(state)
est store e4
estout e1 e2 e3 e4, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)))

reg i pl280_edit onres pl280onres incpc_ln indianppop dist_ln reg15_i reg30_i coborrow refi loanterm_ln loan_ln casinos i.ol i.sl i.year if i!=0 & ol_originatinglender=="Wells Fargo Bank NA" | sl_servicinglender=="Wells Fargo Bank NA", r cluster(state)
est store e5
estout e5, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)))

** Table 5 **
teffects nnmatch (i onres incpc_ln indianppop dist_ln reg15_i reg30_i coborrow refi loanterm_ln loan_ln i.ol i.sl year) (pl280_edit), atet nn(4) ematch(onres) vce(robust) 

** Table 6 **
reg s184_ln pl280_edit incpc_ln indianppop if year==2013, r cluster(state)
est store e1
*reg s184_duplex pl280_edit incpc_ln indianppop if year==2013, r cluster(state)
*reg s184_triplex pl280_edit incpc_ln indianppop if year==2013, r cluster(state)
*reg s184_fourplex pl280_edit incpc_ln indianppop if year==2013, r cluster(state)
estout e1, starlevels(* .1 ** .05 *** .01) cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)))

